@@ -100,7 +100,7 @@ WriteSymTabEntries(FILE *file, const statement_t *stats)
 
     for (stat = stats; stat != stNULL; stat = stat->stNext)
 	if (stat->stKind == skRoutine) {
-	    register	num = stat->stRoutine->rtNumber;
+	    register u_int num = stat->stRoutine->rtNumber;
 	    const char	*name = stat->stRoutine->rtName;
 
 	    while (++current <= num)
@@ -418,7 +418,7 @@ WriteTypeCheck(FILE *file, register const argument_t *arg)
 
     fprintf(file, "#if\tTypeCheck\n");
     if (akCheck(arg->argKind, akbRequestQC))
-	fprintf(file, "\tif (* (int *) &In%dP->%s != * (int *) &%sCheck)\n",
+	fprintf(file, "\tif (BAD_TYPECHECK(&In%dP->%s, &%sCheck))\n",
 		arg->argRequestPos, arg->argTTName, arg->argVarName);
     else
     {
